<?php
/**
 *
 *
 * @author  Bob Ulusoy
 * @copyright Copyright (c) Bob Ulusoy
 * @link  http://artbees.net
 * @since  Version 2.0
 * @package  MK Framework
 */


add_action( 'page_title', 'mk_page_title' );
add_action( 'breadcrumbs', 'mk_breadcrumbs' );
add_action( 'subfooter_social', 'mk_subfooter_social' );








if ( !function_exists( 'mk_page_title' ) ) {
	function mk_page_title( $post_id = NULL ) {
		global $post, $mk_settings;

		$title = $breadcrumb = '';
		$align = 'left';

		if ( is_singular() ) {
			$template = get_post_meta( $post->ID, '_template', true );
			$breadcrumb = get_post_meta( $post->ID, '_breadcrumb', true );
			$align = get_post_meta( $post->ID, '_page_title_align', true );
			$align = ($align != '') ? $align : 'left';

			if ( $template == 'no-title' ) return false;
			$title = get_the_title( $post_id );
		}

		if(is_archive() && $mk_settings['archive-page-title'] == 0) return false;

		if(function_exists( 'is_woocommerce' ) && is_woocommerce() && is_shop() && $mk_settings['woo-shop-loop-title'] == 0) return false;

		if(function_exists( 'is_woocommerce' ) && is_woocommerce() && is_singular('product') && $mk_settings['woo-single-show-title'] == 0) return false;

		if(is_singular('post')) {
			if (isset($mk_settings['page-title-blog']) && $mk_settings['page-title-blog'] == 0 ) return false;
		}

		if(is_singular('portfolio')) {
			if (isset($mk_settings['page-title-portfolio']) && $mk_settings['page-title-portfolio'] == 0 ) return false;
		}

		if ( is_search() ) {
			$title = __( 'Search', 'mk_framework' );
		}

		if ( is_archive() ) {
			if ( is_category() ) {
				$title = sprintf( __( 'Category Archive for: "%s"', 'mk_framework' ), single_cat_title( '', false ) );
			}
			elseif ( is_tag() ) {
				$title = sprintf( __( 'Tag Archives for: "%s"', 'mk_framework' ), single_tag_title( '', false ) );
			}
			elseif ( is_day() ) {
				$title = sprintf( __( 'Daily Archive for: "%s"', 'mk_framework' ), get_the_time( 'F jS, Y' ) );
			}
			elseif ( is_month() ) {
				$title = sprintf( __( 'Monthly Archive for: "%s"', 'mk_framework' ), get_the_time( 'F, Y' ) );
			}
			elseif ( is_year() ) {
				$title = sprintf( __( 'Yearly Archive for: "%s"', 'mk_framework' ), get_the_time( 'Y' ) );
			}
			elseif ( is_author() ) {
				if ( get_query_var( 'author_name' ) ) {
					$curauth = get_user_by( 'slug', get_query_var( 'author_name' ) );
				}
				else {
					$curauth = get_userdata( get_query_var( 'author' ) );
				}
				$title = sprintf( __( 'Author Archive for: "%s"' ), $curauth->nickname );
			}
			elseif ( is_tax() ) {
				$term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
				$title = sprintf( __( 'Archives for: "%s"', 'mk_framework' ), $term->name );
			}
		}


		if ( function_exists( 'is_bbpress' ) && is_bbpress() ) {
			if ( bbp_is_forum_archive() ) {
				$title = bbp_get_forum_archive_title();

			} elseif ( bbp_is_topic_archive() ) {
				$title = bbp_get_topic_archive_title();

			} elseif ( bbp_is_single_view() ) {
				$title = bbp_get_view_title();
			} elseif ( bbp_is_single_forum() ) {

				$forum_id = get_queried_object_id();
				$forum_parent_id = bbp_get_forum_parent_id( $forum_id );

				if ( 0 !== $forum_parent_id )
					$title = array_merge( $item, breadcrumbs_plus_get_parents( $forum_parent_id ) );

				$title = bbp_get_forum_title( $forum_id );
			}
			elseif ( bbp_is_single_topic() ) {
				$topic_id = get_queried_object_id();
				$title = bbp_get_topic_title( $topic_id );
			}

			elseif ( bbp_is_single_user() || bbp_is_single_user_edit() ) {
				$title = bbp_get_displayed_user_field( 'display_name' );
			}
		}


		if ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
			if(is_single() && isset($mk_settings['woo-single-title']) && $mk_settings['woo-single-title'] == 1) {
				$terms = get_the_terms( $post->ID, 'product_cat' );
				if(is_array($terms) && $terms != null) {
				foreach ($terms as $term) {
				    $product_category = $term->name;
				    break;
				}
					$title = $product_category;
				} else {
					ob_start();
					woocommerce_page_title();
					$title = ob_get_clean();
				}
			} else {
				ob_start();
				woocommerce_page_title();
				$title = ob_get_clean();
			}
			

		}


		echo '<section id="mk-page-title" class="'.$align.'-align">';
		echo '<div class="mk-grid">';
		if ( function_exists( 'is_woocommerce' ) && is_woocommerce() && is_single() ) {
			echo '<h2 class="mk-page-heading">' . $title . '</h2>';
		} else {
			echo '<h1 class="mk-page-heading">' . $title . '</h1>';
		}

		if($mk_settings['breadcrumb'] != 0) {
			if($breadcrumb != 'false') {
				echo do_action( 'breadcrumbs', $post_id );
			}
		}

		echo '<div class="clearboth"></div></div></section>';


	}

}




if ( !function_exists( 'mk_breadcrumbs' ) ) {
	function mk_breadcrumbs( $post_id = NULL ) {
		global $mk_settings;
		$output = '';
		$breadcrumb_skin = (isset($mk_settings['breadcrumb-skin']) && !empty($mk_settings['breadcrumb-skin'])) ? $mk_settings['breadcrumb-skin'].'-skin' : 'dark-skin';
		if(is_singular()) {
			$single_breadcrumb = get_post_meta( $post_id, '_breadcrumb_skin', true );
			$breadcrumb_skin = !empty($single_breadcrumb) ?  ($single_breadcrumb . '-skin') : $breadcrumb_skin;
		}
	

		if ( function_exists( 'mk_breadcrumbs_plus' ) ) {
			$output = mk_breadcrumbs_plus( array(
					'prefix' => '',
					'suffix' => '',
					'title' => false,
					'home' => __( 'Home', 'mk_framework' ),
					'front_page' => false,
					'bold' => false,
					'blog' => __( 'Blog', 'mk_framework' ),
					'echo' => false,
					'el_class' => $breadcrumb_skin,
					'post_id' => $post_id
				) );
		}
		echo $output;

	}
}






if ( !function_exists( 'mk_subfooter_social' ) ) {
	function mk_subfooter_social() {
		global $mk_settings;

		$output = '';

		$output .= '<ul class="mk-footer-social">';

		if(!empty($mk_settings['social-facebook'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-facebook'].'"><i class="mk-icon-facebook"></i></a></li>';
		}
		if(!empty($mk_settings['social-twitter'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-twitter'].'"><i class="mk-icon-twitter"></i></a></li>';
		}
		if(!empty($mk_settings['social-google-plus'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-google-plus'].'"><i class="mk-icon-google-plus"></i></a></li>';
		}
		if(!empty($mk_settings['social-rss'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-rss'].'"><i class="mk-icon-rss"></i></a></li>';
		}
		if(!empty($mk_settings['social-pinterest'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-pinterest'].'"><i class="mk-icon-pinterest"></i></a></li>';
		}
		if(!empty($mk_settings['social-instagram'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-instagram'].'"><i class="mk-icon-instagram"></i></a></li>';
		}
		if(!empty($mk_settings['social-dribbble'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-dribbble'].'"><i class="mk-icon-dribbble"></i></a></li>';
		}
		if(!empty($mk_settings['social-linkedin'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-linkedin'].'"><i class="mk-icon-linkedin"></i></a></li>';
		}
		if(!empty($mk_settings['social-tumblr'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-tumblr'].'"><i class="mk-icon-tumblr"></i></a></li>';
		}
		if(!empty($mk_settings['social-youtube'])) {
			$output .= '<li><a target="_blank" href="'.$mk_settings['social-youtube'].'"><i class="mk-icon-youtube"></i></a></li>';
		}

		$output .= '</ul>';

		echo $output;
	}
}
