<?php
/**
 *
 *
 * @author  Bob Ulusoy
 * @copyright Copyright (c) Bob Ulusoy
 * @link  http://artbees.net
 * @since  Version 2.0
 * @package  MK Framework
 */



add_action( 'header_logo', 'mk_header_logo' );
add_action( 'main_navigation', 'mk_main_navigation' );
add_action( 'header_search', 'mk_header_search' );
add_action( 'header_search_form', 'mk_header_search_form' );

add_action( 'side_dashboard', 'mk_side_dashboard' );
add_action( 'dashboard_trigger_link', 'mk_dashboard_trigger_link' );
add_action( 'responsive_nav_trigger_link', 'mk_responsive_nav_trigger_link' );




/*
* Create Header Logo
******/
if ( !function_exists( 'mk_header_logo' ) ) {
	function mk_header_logo() {

		global $mk_settings, $post;

		$light_logo = isset($mk_settings['logo-light']['url']) ? $mk_settings['logo-light']['url'] : '';
		$light_logo_retina = isset($mk_settings['logo-light-retina']['url']) ? $mk_settings['logo-light-retina']['url'] : '';

		$mobile_logo = isset($mk_settings['logo-light']['url']) ? $mk_settings['mobile-logo']['url'] : '';
		$mobile_logo_retina = isset($mk_settings['logo-light-retina']['url']) ? $mk_settings['mobile-logo-retina']['url'] : '';

		$mobile_logo_csss = (!empty($mobile_logo)) ? 'mobile-menu-exists' : '';

		$output = '<li class="mk-header-logo '.$mobile_logo_csss.'">';
		$output .= '<a href="'.home_url( '/' ).'" title="'.get_bloginfo( 'name' ).'">';

		if ( !empty( $mk_settings['logo']['url'] ) ) {
			$output .= '<img alt="'.get_bloginfo( 'name' ).'" class="mk-dark-logo" src="'.$mk_settings['logo']['url'].'" data-retina-src="'.$mk_settings['logo-retina']['url'].'" />';
		} else {
			$output .= '<img alt="'.get_bloginfo( 'name' ).'" class="mk-dark-logo" src="'.THEME_IMAGES.'/ken-logo.png" data-retina-src="'.THEME_IMAGES.'/ken-logo-2x.png" />';
		}

		if ( !empty( $mobile_logo) ) {
			$output .= '<img alt="'.get_bloginfo( 'name' ).'" class="mk-mobile-logo" src="'.$mobile_logo.'" data-retina-src="'.$mobile_logo_retina.'" />';
		}

		if ( !empty( $light_logo ) ) {
			$output .= '<img alt="'.get_bloginfo( 'name' ).'" class="mk-light-logo" src="'.$light_logo.'" data-retina-src="'.$light_logo_retina.'" />';
		}


		$output .= '</a></li>';

		echo $output;

	}
}
/***************************************/







/*
* Create Main Navigation
******/
if ( !function_exists( 'mk_main_navigation' ) ) {
	function mk_main_navigation($menu_location) {

		global $mk_settings;


		$output = '<nav id="mk-main-navigation">';

		$output .= wp_nav_menu( array(
				'theme_location' => $menu_location,
				'container' => false,
				'container_id' => false,
				'container_class' => false,
				'menu_class' => 'main-navigation-ul',
				'echo' => false,
				'fallback_cb' => 'link_to_menu_editor',
				'walker' => new mk_custom_walker
			) );

		$output .= '</nav>';

		if($mk_settings['header-search']) {
			ob_start();
			do_action( 'header_search_form' );
			$output .= ob_get_contents();
			ob_end_clean();
		}	

		echo $output;

	}
}
/***************************************/




/*
* Fallback menu
******/
if ( !function_exists( 'link_to_menu_editor' ) ) {
	function link_to_menu_editor( $args ) {
	    if ( ! current_user_can( 'manage_options' ) )
	    {
	        return;
	    }
	    extract( $args );

	    $link = $link_before
	        . '<a href="' .admin_url( 'nav-menus.php' ) . '">' . $before . 'Add a menu' . $after . '</a>'
	        . $link_after;

	    if ( FALSE !== stripos( $items_wrap, '<ul' )
	        or FALSE !== stripos( $items_wrap, '<ol' )
	    )
	    {
	        $link = "<li class='menu-item'>$link</li>";
	    }

	    ob_start();
		do_action( 'header_logo' );
		$link .= ob_get_contents();
		ob_end_clean();

		ob_start();
		do_action( 'header_search' );
		$link .= ob_get_contents();
		ob_end_clean();


	    $output = sprintf( $items_wrap, $menu_id, $menu_class, $link );
	    if ( ! empty ( $container ) )
	    {
	        $output  = "<$container class='$container_class' id='$container_id'>$output</$container>";
	    }

	    if ( $echo )
	    {
	        echo $output;
	    }

	    return $output;
	}
}




/*
* Create Header Search HTML content
******/
if ( !function_exists( 'mk_header_search' ) ) {
	function mk_header_search() {

	echo '<li class="mk-header-search">
			<a class="header-search-icon" href="#"><i class="mk-icon-search"></i></a>
		</li>';

	}
}
/***************************************/




/*
* Create Header Search Form HTML content
******/
if ( !function_exists( 'mk_header_search_form' ) ) {
	function mk_header_search_form() {

	echo '<form method="get" class="header-searchform-input" action="'.home_url().'">
            <input class="search-ajax-input" type="text" value="" name="s" id="s" />
            <input value="" type="submit" />
            <a href="#" class="header-search-close"><i class="mk-theme-icon-cancel"></i></a>
   		 </form>';

	}
}
/***************************************/



/*
* Create Header Dashboard trigger link Form HTML content. Please note that this link will appear in reposnive mode.
******/
if ( !function_exists( 'mk_dashboard_trigger_link' ) ) {
	function mk_dashboard_trigger_link() {

		echo '<li class="dashboard-trigger res-mode"><i class="mk-theme-icon-dashboard"></i></li>';

	}
}
/***************************************/


/*
* Create Responsive Navigation trigger link Form HTML content. Please note that this link will appear in reposnive mode.
******/
if ( !function_exists( 'mk_responsive_nav_trigger_link' ) ) {
	function mk_responsive_nav_trigger_link() {

		echo '<li class="responsive-nav-link"><i class="mk-theme-icon-responsive"></i></li>';

	}
}
/***************************************/






/*
* Append Header elements to Main Navigation list items.
******/
if ( !function_exists( 'add_first_nav_item' ) ) {
	function add_first_nav_item( $items, $args ) {
		global $mk_settings;
		$output = '';
		if ( !is_admin() && ($args->theme_location == 'primary-menu' || $args->theme_location == 'second-menu' || $args->theme_location == 'third-menu' || $args->theme_location == 'fourth-menu' || $args->theme_location == 'fifth-menu' || $args->theme_location == 'sixth-menu' || $args->theme_location == 'seventh-menu') ) {
			
			ob_start();
			do_action( 'responsive_nav_trigger_link' );
			$output .= ob_get_contents();
			ob_end_clean();
				
			ob_start();
			do_action( 'header_logo' );
			$output .= ob_get_contents();
			ob_end_clean();

			$output .= $items;

			if($mk_settings['side-dashboard']) {
				ob_start();
				do_action( 'dashboard_trigger_link' );
				$output .= ob_get_contents();
				ob_end_clean();
			}

			if ( class_exists( 'woocommerce' ) ) {	
				if($mk_settings['checkout-box']) {
					ob_start();
					do_action( 'header_checkout' );
					$output .= ob_get_contents();
					ob_end_clean();
				}
			}
				
			if($mk_settings['header-search']) {
				ob_start();
				do_action( 'header_search' );
				$output .= ob_get_contents();
				ob_end_clean();
			}	
			
			
		} else {
			$output .= $items;
		}
		return $output;
	}
	add_filter( 'wp_nav_menu_items', 'add_first_nav_item', 10, 2 );
}
/***************************************/








/*
* Create Side Dashboard
******/
if ( !function_exists( 'mk_side_dashboard' ) ) {
	function mk_side_dashboard() {
		global $mk_settings;

	if($mk_settings['side-dashboard']) {
		$output = '';
		$output .= '<div class="mk-side-dashboard">';
		//$output .= '<span class="mk-sidedasboard-close"><i class="mk-theme-icon-cancel"></i></span>';
		ob_start();
		dynamic_sidebar('Side Dashboard');
		$output .= ob_get_contents();
		ob_end_clean();

		$output .= '</div>';

		echo $output;
	}	

	}
}
/***************************************/











